@@ -1,5 +1,5 @@
-// $Id: ArcBox.h,v 1.9 1998/03/25 12:42:14 zeller Exp $
-// Klasse ArcBox (Deklaration)
+// $Id: ArcBox.h,v 1.11 1998/11/23 15:00:15 zeller Exp $
+// Arc boxes
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
 // Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
@@ -49,8 +49,8 @@ public:
     DECLARE_TYPE_INFO
 
 private:
-    BoxDegrees _start;     // Beginn Bogen
-    BoxDegrees _length;    // Laenge Bogen
+    BoxDegrees _start;     // Start of arc
+    BoxDegrees _length;    // Length of arc
 
     void __draw(Widget w, 
 		const BoxRegion& region, 
@@ -60,10 +60,10 @@ private:
 
     void _printPS(ostream& os, 
 		  const BoxRegion& region, 
-		  const BoxPrintGC& gc) const;
+		  const PrintGC& gc) const;
     void _printFig(ostream& os, 
 		   const BoxRegion& region, 
-		   const BoxPrintGC& gc) const;
+		   const PrintGC& gc) const;
 	
 protected:
     ArcBox(const ArcBox& box):
@@ -80,18 +80,18 @@ protected:
     }
 
 public:
-    ArcBox(BoxDegrees start, BoxDegrees length, BoxCoordinate linethickness = 1, 
-	char * t = "ArcBox"):
-	LineBox(linethickness, t), _start(start), _length(length)
+    ArcBox(BoxDegrees start, BoxDegrees length,
+	   BoxCoordinate linethickness = 1, char * t = "ArcBox")
+	: LineBox(linethickness, t), _start(start), _length(length)
     {}
 
     Box *dup() const { return new ArcBox(*this); }
 
     virtual void _print(ostream& os, 
 			const BoxRegion& region, 
-			const BoxPrintGC& gc) const;
+			const PrintGC& gc) const;
 
-    // Ressourcen
+    // Resources
     BoxDegrees start() const { return _start; }
     BoxDegrees length() const { return _length; }
 };
