@@ -1,5 +1,5 @@
-// $Id: PrimitiveB.h,v 1.9 1998/03/25 12:44:00 zeller Exp $
-// Klasse PrimitiveBox und folgende (Deklaration)
+// $Id: PrimitiveB.h,v 1.11 1998/11/23 17:43:33 zeller Exp $
+// Primitive boxes
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
 // Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
@@ -82,7 +82,7 @@ public:
     Box *dup() const { return new RuleBox(*this); }
     void _print(ostream& os, 
 		const BoxRegion& r, 
-		const BoxPrintGC& gc) const;
+		const PrintGC& gc) const;
 };
 
 
@@ -109,7 +109,7 @@ protected:
 public:
     void _print(ostream&, 
 		const BoxRegion&, 
-		const BoxPrintGC&) const
+		const PrintGC&) const
     {
 	// do nothing
     }
