@@ -1,4 +1,4 @@
-// $Id: SourceView.h,v 1.143.4.1 1998/12/10 16:32:53 zeller Exp $
+// $Id: SourceView.h,v 1.143.4.2 1999/03/14 15:40:32 zeller Exp $
 // View the Source.
 
 // Copyright (C) 1995-1997 Technische Universitaet Braunschweig, Germany.
@@ -535,6 +535,10 @@ private:
     static Widget drag_conds[2];
     static Widget drag_temps[2];
 
+    // Return position POS of glyph GLYPH in X/Y.  Return true iff displayed.
+    static bool glyph_pos_to_xy(Widget glyph, XmTextPosition pos,
+				Position& x, Position& y);
+
     // Map stop sign in W at position POS.  Get widget from STOPS[COUNT];
     // store location in POSITIONS.  Return mapped widget (0 if none)
     static Widget map_stop_at(Widget w, XmTextPosition pos,
