@@ -196,6 +196,9 @@
 /* Define if gethostname is declared in unistd.h. */
 #undef HAVE_GETHOSTNAME_DECL
 
+/* Define if getpt is declared in stdlib.h. */
+#undef HAVE_GETPT_DECL
+
 /* Define if getpty is declared in unistd.h. */
 #undef HAVE_GETPTY_DECL
 
