@@ -1,4 +1,4 @@
-// $Id: logo.h,v 1.18 1998/04/29 15:31:49 zeller Exp $ -*- C++ -*-
+// $Id: logo.h,v 1.21 1998/10/03 17:22:37 zeller Exp $ -*- C++ -*-
 // DDD logos and logo functions
 
 // Copyright (C) 1996-1998 Technische Universitaet Braunschweig, Germany.
@@ -45,12 +45,21 @@ extern Pixmap iconlogo(Widget shell);
 extern Pixmap iconmask(Widget shell);
 
 // Return the DDD splash screen.  COLOR_KEY indicates the XPM visual type.
-extern Pixmap dddsplash(Widget shell, const string& color_key = 'c');
+extern Pixmap dddsplash(Widget shell, 
+			const string& color_key,
+			Dimension& width, Dimension& height);
 
 // Install toolbar icons in Motif cache.  COLOR_KEY indicates the XPM
-// visual type. If STRIP_CAPTIONS is greater than 0, strip this number
-// of pixels from the bottom of toolbar icons.
-extern void install_icons(Widget shell, const string& color_key = 'c');
+// visual type for inactive buttons.  ACTIVE_COLOR_KEY is the XPM visual
+// type for active buttons (entered or armed).
+extern void install_icons(Widget shell, 
+			  const string& color_key,
+			  const string& active_color_key);
+inline void install_icons(Widget shell, 
+			  const string& color_key = 'c')
+{
+    install_icons(shell, color_key, color_key);
+}
 
 // Set label of W to NEW_LABEL (and its pixmap to IMAGE_NAME, if given)
 extern void set_label(Widget w, const MString& new_label, 
@@ -73,6 +82,7 @@ extern void set_label(Widget w, const MString& new_label,
 #define NEW_BREAK_ICON     "new_break"
 #define NEW_DISPLAY_ICON   "new_display"
 #define NEW_WATCH_ICON     "new_watch"
+#define PLOT_ICON          "plot"
 #define PRINT_ICON         "print"
 #define PROPERTIES_ICON    "properties"
 #define ROTATE_ICON        "rotate"
