@@ -1,4 +1,4 @@
-// $Id: strclass.h,v 1.25 1998/06/15 17:25:36 zeller Exp $
+// $Id: strclass.h,v 1.31 1998/11/26 09:31:22 zeller Exp $
 // A string class (based on `String' from GNU libg++-2.3)
 
 // This may look like C code, but it is really -*- C++ -*-
@@ -377,6 +377,29 @@ Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 //      next string operation,  and you must not modify it.  (The
 //      conversion is defined to return a const value so that GNU C++ will
 //      produce warning and/or error messages if changes are attempted.)
+//
+//
+// Special stuff
+// =============
+// 
+// A string S can be put into `consuming' mode by invoking
+// 
+//     s.consuming(true)
+// 
+// While in `consuming' mode, the (physical) location of S does not change;
+// the only assignment operations allowed are assignments of substrings
+// at the end of S, as in
+// 
+//     s = s.from(...); s = s.after(...)
+//
+// Furthermore, pointers to S stay constant; it is safe to refer to an
+// earlier value of S via a pointer:
+//
+//     char *s0 = s;
+//     s = s.after(...);;
+//     // S0 still points to original S here
+// 
+// This feature is used in DDD to speed up several loops.
 
 
 #ifndef _ICE_strclass_h
@@ -391,14 +414,21 @@ Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 #include "rxclass.h"
 #include "config.h"
 #include "bool.h"
+#include "assert.h"
+
+#ifndef STRING_CHECK_CONSUME
+#define STRING_CHECK_CONSUME 0
+#endif
 
 // Internal string representations
 struct strRep
 {
-    unsigned len;		// String length 
-    unsigned sz;		// Allocated space
-    char s[1];			// The string starts here 
-				// (at least 1 char for trailing null)
+    unsigned int len;		// String length
+    unsigned int allocated;     // Allocated space
+    char *s;			// Start of string; points into
+				// MEM[0]..MEM[ALLOCATED - 1]
+    char mem[1];                // Start of memory
+    				// (at least 1 char for trailing null)
 				// Allocated & expanded via non-public fcts
 };
 
@@ -477,7 +507,10 @@ class string
     friend class subString;
 
 protected:
-    strRep* rep;   // Strings are pointers to their representations
+    strRep* rep;	 // Strings are pointers to their representations
+#if STRING_CHECK_CONSUME
+    bool consume;	 // If true, check that we're only consuming
+#endif
 
     // Some helper functions
     int search(int, int, const char*, int = -1) const;
@@ -490,8 +523,14 @@ protected:
 
 private:
     // Don't get constructed or assigned from int
-    string(int) : rep(0)      { error("init from int"); }
-    string& operator = (int)  { error("int assign"); return *this; }
+    string(int) : rep(0)
+#if STRING_CHECK_CONSUME
+	, consume(false)
+#endif
+    { 
+	error("init from int");
+    }
+    string& operator = (int)             { error("int assign"); return *this; }
 
 public:
     // Constructors and assignment
@@ -505,6 +544,9 @@ public:
 
     ~string();
 
+    void consuming(bool set);
+    bool consuming() const;
+
     string& operator = (const string& y);
     string& operator = (const char* y);
     string& operator = (char* y);
@@ -718,9 +760,9 @@ public:
 
     // Friends & utilities
     // Split string into array RES at SEPARATORS; return number of elements
-    friend int split(const string& x, string res[], int maxn, 
+    friend int split(const string& x, string *res, int maxn, 
 		     const string& sep);
-    friend int split(const string& x, string res[], int maxn, 
+    friend int split(const string& x, string *res, int maxn, 
 		     const regex& sep);
 
     friend string common_prefix(const string& x, const string& y, 
@@ -729,7 +771,7 @@ public:
 				int startpos = -1);
     // friend string replicate(char c, int n);
     friend string replicate(const string& y, int n);
-    friend string join(string src[], int n, const string& sep);
+    friend string join(string *src, int n, const string& sep);
 
     // Simple builtin transformations
     friend inline string reverse(const string& x);
@@ -821,26 +863,75 @@ extern string _nilstring;
 
 inline unsigned int string::length() const {  return rep->len; }
 inline int          string::empty() const { return rep->len == 0; }
-inline const char*  string::chars() const { return &(rep->s[0]); }
-inline int          string::allocation() const { return rep->sz; }
+inline const char*  string::chars() const { return rep->s; }
+inline int          string::allocation() const { return rep->allocated; }
 
 inline unsigned int subString::length() const { return len; }
 inline int          subString::empty() const { return len == 0; }
-inline const char*  subString::chars() const { return &(S.rep->s[pos]); }
+inline const char*  subString::chars() const { return S.rep->s + pos; }
+
+// Resources
+inline void string::consuming(bool set)
+{
+#if STRING_CHECK_CONSUME
+    consume = set;
+#else
+    (void) set;
+#endif
+}
+
+inline bool string::consuming() const
+{
+#if STRING_CHECK_CONSUME
+    return consume;
+#else
+    return false;
+#endif
+}
 
 // Constructors
 inline string::string() 
-  : rep(&_nilstrRep) {}
-inline string::string(const string& x) 
-  : rep(string_Scopy(0, x.rep)) {}
+  : rep(&_nilstrRep)
+#if STRING_CHECK_CONSUME
+    , consume(false) 
+#endif
+  {}
+
+inline string::string(const string& x)
+  : rep(string_Scopy(0, x.rep))
+#if STRING_CHECK_CONSUME
+    , consume(false) 
+#endif
+  {}
+
 inline string::string(const char* t) 
-  : rep(string_Salloc(0, t, -1, -1)) {}
+  : rep(string_Salloc(0, t, -1, -1))
+#if STRING_CHECK_CONSUME
+    , consume(false) 
+#endif
+  {}
+
 inline string::string(const char* t, int tlen)
-  : rep(string_Salloc(0, t, tlen, tlen)) {}
+  : rep(string_Salloc(0, t, tlen, tlen))
+#if STRING_CHECK_CONSUME
+    , consume(false) 
+#endif
+  {}
+
 inline string::string(const subString& y)
-  : rep(string_Salloc(0, y.chars(), y.length(), y.length())) {}
+  : rep(string_Salloc(0, y.chars(), y.length(), y.length()))
+#if STRING_CHECK_CONSUME
+    , consume(false) 
+#endif
+  {}
+
 inline string::string(char c) 
-  : rep(string_Salloc(0, &c, 1, 1)) {}
+  : rep(string_Salloc(0, &c, 1, 1))
+#if STRING_CHECK_CONSUME
+    , consume(false) 
+#endif
+  {}
+
 
 // For HAVE_PLACEMENT_NEW, if using placement new, use operator
 // delete instead of vector delete.
@@ -870,41 +961,86 @@ inline subString::subString(const string& x, int first, int l)
 
 inline subString::~subString() {}
 
-// Assignment
+// String Assignment
+
 inline string& string::operator = (const string& y)
-{ 
+{
+    assert(!consuming());
     rep = string_Scopy(rep, y.rep); return *this;
 }
 
 inline string& string::operator = (const char* t)
 {
-    rep = string_Salloc(rep, t, -1, -1); return *this;
+    if (t >= rep->s && t < rep->s + rep->len)
+    {
+	// Assignment of self-substring
+	int len = t - rep->s;
+	rep->len -= len;
+	rep->s = (char *)t;
+    }
+    else if (t >= &(rep->mem[0]) && t < rep->s)
+    {
+	// Assignment of older base mem
+	int len = (rep->s - t);
+	rep->len += len;
+	rep->s = (char *)t;
+    }
+    else
+    {
+	assert(!consuming());
+	rep = string_Salloc(rep, t, -1, -1);
+    }
+    return *this;
 }
 
-inline string& string::operator = (char* t)
+inline string& string::operator = (char *t)
 {
-    rep = string_Salloc(rep, t, -1, -1); return *this;
+    return operator = ((const char *)t);
 }
 
 inline string& string::operator = (const subString&  y)
 {
-    rep = string_Salloc(rep, y.chars(), y.length(), y.length()); return *this;
+    if (y.chars() >= &(rep->mem[0]) && 
+	y.chars() < &(rep->mem[0]) + rep->allocated)
+    {
+	// Assignment of self-substring
+	rep->s   = (char *)y.chars();
+	rep->len = y.length();
+	rep->s[rep->len] = '\0';
+    }
+    else
+    {
+	assert(!consuming());
+	rep = string_Salloc(rep, y.chars(), y.length(), y.length());
+    }
+    return *this;
 }
 
 inline string& string::operator = (char c)
 {
+    assert(!consuming());
     rep = string_Salloc(rep, &c, 1, 1); return *this;
 }
 
 inline string& string::operator = (ostrstream& os)
 {
+    assert(!consuming());
+
 #if HAVE_FROZEN_OSTRSTREAM
     // No need to freeze the stream, since the string is copied right away
     int frozen = os.frozen();
 #endif
 
     const char *str = os.str();
+#if OSTRSTREAM_PCOUNT_BROKEN
+    // In the SGI C++ I/O library, accessing os.str() *increases*
+    // os.pcount() by 1.  We could compensate this in a
+    // machine-independent way by fetching pcount() before str(), but
+    // this will cause trouble when os is assigned the next time.
+    rep = string_Salloc(rep, str, os.pcount() - 1, os.pcount() - 1);
+#else
     rep = string_Salloc(rep, str, os.pcount(), os.pcount());
+#endif
 
 #if HAVE_FROZEN_OSTRSTREAM
     os.freeze(frozen);
@@ -913,11 +1049,17 @@ inline string& string::operator = (ostrstream& os)
 }
 
 inline string::string(ostrstream& os)
-    : rep(&_nilstrRep) 
+    : rep(&_nilstrRep)
+#if STRING_CHECK_CONSUME
+    , consume(false) 
+#endif
 {
     operator=(os);
 }
 
+
+// Substring assignments
+
 inline subString& subString::operator = (const char* ys)
 {
     assign(0, ys); return *this;
@@ -947,126 +1089,151 @@ inline subString& subString::operator = (const subString& y)
 
 inline void cat(const string& x, const string& y, string& r)
 {
+    assert(!r.consuming());
     r.rep = string_Scat(r.rep, x.chars(), x.length(), y.chars(), y.length());
 }
 
 inline void cat(const string& x, const subString& y, string& r)
 {
+    assert(!r.consuming());
     r.rep = string_Scat(r.rep, x.chars(), x.length(), y.chars(), y.length());
 }
 
 inline void cat(const string& x, const char* y, string& r)
 {
+    assert(!r.consuming());
     r.rep = string_Scat(r.rep, x.chars(), x.length(), y, -1);
 }
 
 inline void cat(const string& x, char* y, string& r)
 {
+    assert(!r.consuming());
     r.rep = string_Scat(r.rep, x.chars(), x.length(), y, -1);
 }
 
 inline void cat(const string& x, char y, string& r)
 {
+    assert(!r.consuming());
     r.rep = string_Scat(r.rep, x.chars(), x.length(), &y, 1);
 }
 
 inline void cat(const subString& x, const string& y, string& r)
 {
+    assert(!r.consuming());
     r.rep = string_Scat(r.rep, x.chars(), x.length(), y.chars(), y.length());
 }
 
 inline void cat(const subString& x, const subString& y, string& r)
 {
+    assert(!r.consuming());
     r.rep = string_Scat(r.rep, x.chars(), x.length(), y.chars(), y.length());
 }
 
 inline void cat(const subString& x, const char* y, string& r)
 {
+    assert(!r.consuming());
     r.rep = string_Scat(r.rep, x.chars(), x.length(), y, -1);
 }
 
 inline void cat(const subString& x, char* y, string& r)
 {
+    assert(!r.consuming());
     r.rep = string_Scat(r.rep, x.chars(), x.length(), y, -1);
 }
 
 inline void cat(const subString& x, char y, string& r)
 {
+    assert(!r.consuming());
     r.rep = string_Scat(r.rep, x.chars(), x.length(), &y, 1);
 }
 
 inline void cat(const char* x, const string& y, string& r)
 {
+    assert(!r.consuming());
     r.rep = string_Scat(r.rep, x, -1, y.chars(), y.length());
 }
 
 inline void cat(const char* x, const subString& y, string& r)
 {
+    assert(!r.consuming());
     r.rep = string_Scat(r.rep, x, -1, y.chars(), y.length());
 }
 
 inline void cat(const char* x, const char* y, string& r)
 {
+    assert(!r.consuming());
     r.rep = string_Scat(r.rep, x, -1, y, -1);
 }
 
 inline void cat(const char* x, char* y, string& r)
 {
+    assert(!r.consuming());
     r.rep = string_Scat(r.rep, x, -1, y, -1);
 }
 
 inline void cat(const char* x, char y, string& r)
 {
+    assert(!r.consuming());
     r.rep = string_Scat(r.rep, x, -1, &y, 1);
 }
 
 inline void cat(char* x, const string& y, string& r)
 {
+    assert(!r.consuming());
     r.rep = string_Scat(r.rep, x, -1, y.chars(), y.length());
 }
 
 inline void cat(char* x, const subString& y, string& r)
 {
+    assert(!r.consuming());
     r.rep = string_Scat(r.rep, x, -1, y.chars(), y.length());
 }
 
 inline void cat(char* x, const char* y, string& r)
 {
+    assert(!r.consuming());
     r.rep = string_Scat(r.rep, x, -1, y, -1);
 }
 
 inline void cat(char* x, char* y, string& r)
 {
+    assert(!r.consuming());
     r.rep = string_Scat(r.rep, x, -1, y, -1);
 }
 
 inline void cat(char* x, char y, string& r)
 {
+    assert(!r.consuming());
     r.rep = string_Scat(r.rep, x, -1, &y, 1);
 }
 
 inline void cat(char x, const string& y, string& r)
 {
+    assert(!r.consuming());
     r.rep = string_Scat(r.rep, &x, 1, y.chars(), y.length());
 }
 
 inline void cat(char x, const subString& y, string& r)
 {
+    assert(!r.consuming());
     r.rep = string_Scat(r.rep, &x, 1, y.chars(), y.length());
 }
 
 inline void cat(char x, const char* y, string& r)
 {
+    assert(!r.consuming());
     r.rep = string_Scat(r.rep, &x, 1, y, -1);
 }
 
 inline void cat(char x, char* y, string& r)
 {
+    assert(!r.consuming());
     r.rep = string_Scat(r.rep, &x, 1, y, -1);
 }
 
 inline void cat(char x, char y, string& r)
 {
+    assert(!r.consuming());
     r.rep = string_Scat(r.rep, &x, 1, &y, 1);
 }
 
@@ -1308,26 +1475,31 @@ inline string capitalize(const string& x)
 
 inline string& string::prepend(const string& y)
 {
+    assert(!consuming());
     rep = string_Sprepend(rep, y.chars(), y.length()); return *this;
 }
 
 inline string& string::prepend(const char* y)
 {
+    assert(!consuming());
     rep = string_Sprepend(rep, y, -1); return *this;
 }
 
 inline string& string::prepend(char* y)
 {
+    assert(!consuming());
     rep = string_Sprepend(rep, y, -1); return *this;
 }
 
 inline string& string::prepend(char y)
 {
+    assert(!consuming());
     rep = string_Sprepend(rep, &y, 1); return *this;
 }
 
 inline string& string::prepend(const subString& y)
 {
+    assert(!consuming());
     rep = string_Sprepend(rep, y.chars(), y.length());return *this;
 }
 
@@ -1336,21 +1508,25 @@ inline string& string::prepend(const subString& y)
 
 inline void string::reverse()
 {
+    assert(!consuming());
     rep = string_Sreverse(rep, rep);
 }
 
 inline void string::upcase()
 {
+    assert(!consuming());
     rep = string_Supcase(rep, rep);
 }
 
 inline void string::downcase()
 {
+    assert(!consuming());
     rep = string_Sdowncase(rep, rep);
 }
 
 inline void string::capitalize()
 {
+    assert(!consuming());
     rep = string_Scapitalize(rep, rep);
 }
 
