@@ -1,23 +1,23 @@
-// $Id: string-fun.h,v 1.11 1997/10/03 10:41:46 zeller Exp $
+// $Id: string-fun.h,v 1.13 1998/04/23 08:40:06 zeller Exp $
 // Miscellaneous string functions
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
 // Written by Dorothea Luetkehaus <luetke@ips.cs.tu-bs.de>.
 // 
-// This file is part of the DDD Library.
+// This file is part of DDD.
 // 
-// The DDD Library is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Library General Public
+// DDD is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public
 // License as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
 // 
-// The DDD Library is distributed in the hope that it will be useful,
+// DDD is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-// See the GNU Library General Public License for more details.
+// See the GNU General Public License for more details.
 // 
-// You should have received a copy of the GNU Library General Public
-// License along with the DDD Library -- see the file COPYING.LIB.
+// You should have received a copy of the GNU General Public
+// License along with DDD -- see the file COPYING.
 // If not, write to the Free Software Foundation, Inc.,
 // 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
@@ -60,8 +60,8 @@ int get_nr (const string& s);
 int get_positive_nr (const char* s);
 int get_positive_nr (const string& s);
 
-// Remove leading blanks from S
-void read_leading_blanks (string& value);
+// Remove leading whitespace
+void strip_leading_space (string& value);
 
 // Remove and return a leading integer from S, or "" if none
 string read_nr_str (string& s);
@@ -69,9 +69,16 @@ string read_nr_str (string& s);
 // Remove and return a leading integer from S, or 0 if none
 int read_positive_nr (string& s);
 
-// Strip final characters
-void strip_final_blanks(string& text);
-void strip_final_newlines(string& text);
+// Strip trailing whitespace
+void strip_trailing_space(string& text);
+void strip_trailing_newlines(string& text);
+
+// Strip leading & trailing whitespace
+inline void strip_space(string& text)
+{
+    strip_leading_space(text);
+    strip_trailing_space(text);
+}
 
 #endif // _DDD_string_fun_h
 // DON'T ADD ANYTHING BEHIND THIS #endif
