@@ -9,16 +9,8 @@ typedef struct _IGNORED_YYSTYPE  {
 	string *str;
 	int num;
 	double fnum;
-	struct {
-	    string *id;
-	    VSLNode *pattern;
-	    string *file;
-	    int line;
-	} header;
-	struct {
-	    VSLNode *pattern;
-	    VSLNode *args;
-	} vardef;
+	VSLFunctionHeader function_header;
+	VSLVarDefinition  var_definition;
     };
 } IGNORED_YYSTYPE;
 #define	IDENTIFIER	258
